# PERISTOLE

[![codeastro](https://img.shields.io/badge/Made%20at-Code/Astro-blueviolet.svg)](https://semaphorep.github.io/codeastro/)
![](https://img.shields.io/github/license/centarsirius/peristole)
[![pypi](https://img.shields.io/pypi/v/maglimit)](https://pypi.org/project/peristole/)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.6744001.svg)](https://doi.org/10.5281/zenodo.6744001)
[![Documentation Status](https://readthedocs.org/projects/maglimit/badge/?version=latest)](https://maglimit.readthedocs.io/en/latest/?badge=latest)

## PERISTOLE : PackagE that geneRates tIme delay plotS due To gravitatiOnaL lEnsing

PERISTOLE plots graphs for time delay caused due to different aspects of lensing such as latitudinal, rotational, geomterical, gravitational time delays.
This project was inspired by the series of Rafikov & Lai papers from 2005-06 that focused on a binary pulsar system with its speciality being that the companion pulsar has an almost edge-on configuration with our line of sight which presents a way to test different gravitational problems.
